# © 2022 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models


class ScopMembershipLiasseWizard(models.TransientModel):
    _name = "scop.membership.liasse.wizard"
    _description = "Wizard: Données financières d'adhésion"

    # ------------------------------------------------------
    # Field declaration
    # ------------------------------------------------------
    partner_id = fields.Many2one(
        comodel_name="res.partner", string="Coopérative", required=True
    )
    liasse_id = fields.Many2one(
        comodel_name="scop.liasse.fiscale",
        string="Liasse existante",
    )
    is_financial_data = fields.Boolean(compute="_compute_is_financial_data")
    is_editable = fields.Boolean(compute="_compute_is_editable")

    # Related fields
    is_qualified = fields.Boolean(related="liasse_id.is_qualified")
    year = fields.Integer(related="liasse_id.year")
    type_id = fields.Selection(related="liasse_id.type_id")
    source = fields.Selection(related="liasse_id.source")
    dureeExercice = fields.Integer(related="liasse_id.dureeExercice")
    L2050_DCLO = fields.Date(related="liasse_id.L2050_DCLO")
    currency_id = fields.Many2one(related="liasse_id.currency_id")
    L2052_FL = fields.Monetary(related="liasse_id.L2052_FL")
    av_cg = fields.Monetary(related="liasse_id.av_cg")
    av_lf = fields.Monetary(related="liasse_id.av_lf")
    L2052_FY = fields.Monetary(related="liasse_id.L2052_FY")
    L2053_HN = fields.Float(related="liasse_id.L2053_HN")
    contribution_base_type = fields.Selection(
        related="liasse_id.contribution_base_type"
    )
    contribution_base_amount = fields.Integer(
        related="liasse_id.contribution_base_amount"
    )
    contribution_cg = fields.Float(related="liasse_id.contribution_cg")
    contribution_hdf = fields.Float(related="liasse_id.contribution_hdf")
    contribution_med = fields.Float(related="liasse_id.contribution_med")
    contribution_com = fields.Float(related="liasse_id.contribution_com")
    contribution_cae = fields.Float(related="liasse_id.contribution_cae")
    contribution_indus = fields.Float(related="liasse_id.contribution_indus")

    # ------------------------------------------------------
    # Compute
    # ------------------------------------------------------
    def _compute_is_financial_data(self):
        for wizard in self:
            liasse_ids = self.env["scop.liasse.fiscale"].search(
                [("partner_id", "=", wizard.partner_id.id)]
            )
            wizard.is_financial_data = True if liasse_ids else False

    @api.depends("liasse_id")
    def _compute_is_editable(self):
        for wizard in self:
            if wizard.liasse_id.type_id == "forecast":
                wizard.is_editable = True
            else:
                wizard.is_editable = False

    # ------------------------------------------------------
    # Actions / Buttons
    # ------------------------------------------------------
    def save_data(self):
        """
        Sauvegarder les données même avec erreurs
        """
        self.partner_id.liasse_membership_id = self.liasse_id
        return {"type": "ir.actions.act_window_close"}

    def new_forecast(self):
        liasse_values = {
            "partner_id": self.partner_id.id,
            "year": fields.Date.today().year,
            "effective_date": fields.Date.today(),
            "source": "manual",
            "type_id": "forecast",
            "is_qualified": True,
        }
        liasse_id = self.env["scop.liasse.fiscale"].create(liasse_values)
        self.partner_id.liasse_membership_id = liasse_id

        return self.open_forecast(liasse_id)

    def update_forecast(self):
        return self.open_forecast(self.liasse_id)

    # ------------------------------------------------------
    # Business function
    # ------------------------------------------------------
    def open_forecast(self, liasse_id):
        action = self.env["ir.actions.actions"]._for_xml_id(
            "cgscop_liasse_fiscale.scop_liasse_fiscale_previsionnelle_act_window"
        )
        self.partner_id.liasse_membership_id = liasse_id
        action.update(
            {
                "target": "new",
                "res_id": liasse_id.id,
                "flags": {"action_buttons": False},
            }
        )
        return action
