# © 2022 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import fields, models


class ScopMembershipStaffWizard(models.TransientModel):
    _name = "scop.membership.staff.wizard"
    _description = "Wizard: création modification de l'effectif d'adhésion"

    # ------------------------------------------------------
    # Field declaration
    # ------------------------------------------------------
    partner_id = fields.Many2one(comodel_name="res.partner", required=True)
    staff_id = fields.Many2one(
        comodel_name="scop.partner.staff",
    )
    effective_date = fields.Date(
        related="staff_id.effective_date", readonly=False, store=True
    )
    staff_count = fields.Integer(
        related="staff_id.staff_count", readonly=False, store=True
    )
    staff_shareholder_count = fields.Integer(
        related="staff_id.staff_shareholder_count", readonly=False, store=True
    )
    staff_shareholder_total = fields.Integer(
        related="staff_id.staff_shareholder_total", readonly=False, store=True
    )
    staff_average = fields.Float(
        related="staff_id.staff_average", readonly=False, store=True
    )
    comment = fields.Char(related="staff_id.comment", readonly=False, store=True)

    # ------------------------------------------------------
    # Actions / Buttons
    # ------------------------------------------------------
    def save_data(self):
        """
        Sauvegarder les données même avec erreurs
        """
        if self.staff_id:
            return {"type": "ir.actions.act_window_close"}
        else:
            return self.staff_id.create(
                {
                    "partner_id": self.partner_id.id,
                    "type_entry": "membership",
                    "effective_date": self.effective_date,
                    "staff_count": self.staff_count,
                    "staff_shareholder_count": self.staff_shareholder_count,
                    "staff_shareholder_total": self.staff_shareholder_total,
                    "staff_average": self.staff_average,
                    "comment": self.comment,
                }
            )
